@@ -50,7 +50,7 @@ proc ColorMainMenu {} {
     $ds9(mb).color add cascade -label [msgcat::mc {Colorbar}] \
 	-menu $ds9(mb).color.colorbar
     $ds9(mb).color add separator
-    $ds9(mb).color add command -label "[msgcat::mc {Colormap Parameters}]..." \
+    $ds9(mb).color add command -label [msgcat::mc {Colormap Parameters}] \
 	-command ColormapDialog
 
     ThemeMenu $ds9(mb).color.colorbar
@@ -62,10 +62,10 @@ proc ColorMainMenu {} {
 	-menu $ds9(mb).color.colorbar.cb 
     $ds9(mb).color.colorbar add separator
     $ds9(mb).color.colorbar add command \
-	-label "[msgcat::mc {Size}]..." \
+	-label [msgcat::mc {Size}] \
 	-command ColorbarSizeDialog
     $ds9(mb).color.colorbar add command \
-	-label "[msgcat::mc {Number of Ticks}]..." \
+	-label [msgcat::mc {Number of Ticks}] \
 	-command TicksDialog
 
     ThemeMenu $ds9(mb).color.colorbar.orient
@@ -280,24 +280,24 @@ proc CreateButtonsColor {} {
     CreateButtonsColorExternal topo
 
     CheckButton $ds9(buttons).color.invert \
-	[string tolower [msgcat::mc {Invert}]] colorbar(invert) InvertColorbar
+	[string tolower [msgcat::mc {Invert}]] colorbar invert InvertColorbar
     ButtonButton $ds9(buttons).color.reset \
 	[string tolower [msgcat::mc {Reset}]] ResetColormap
     RadioButton $ds9(buttons).color.horz \
 	[string tolower [msgcat::mc {Horizontal}]] \
-	colorbar(orientation) 0 ColorbarUpdateView
+	colorbar orientation 0 ColorbarUpdateView
     RadioButton $ds9(buttons).color.vert \
 	[string tolower [msgcat::mc {Vertical}]] \
-	colorbar(orientation) 1 ColorbarUpdateView
+	colorbar orientation 1 ColorbarUpdateView
     CheckButton $ds9(buttons).color.numerics \
 	[string tolower [msgcat::mc {Numerics}]] \
-	colorbar(numerics) ColorbarUpdateView
+	colorbar numerics ColorbarUpdateView
     RadioButton $ds9(buttons).color.numvalue \
 	[string tolower [msgcat::mc {Value}]] \
-	colorbar(space) 1 ColorbarUpdateView
+	colorbar space 1 ColorbarUpdateView
     RadioButton $ds9(buttons).color.numspace \
 	[string tolower [msgcat::mc {Distance}]] \
-	colorbar(space) 0 ColorbarUpdateView
+	colorbar space 0 ColorbarUpdateView
 
     ButtonButton $ds9(buttons).color.params \
 	[string tolower [msgcat::mc {Parameters}]] ColormapDialog
@@ -320,7 +320,7 @@ proc CreateButtonsColorExternal {which} {
     
     foreach cmap $icolorbar($which,cmaps) {
 	RadioButton $ds9(buttons).color.$cmap [msgcat::mc $cmap] \
-	    colorbar(map) $cmap [list ChangeColormapName $cmap]
+	    colorbar map $cmap [list ChangeColormapName $cmap]
 
 	append buttons(color) "$ds9(buttons).color.$cmap pbuttons(color,$cmap) "
     }
@@ -366,7 +366,7 @@ proc PrefsDialogButtonbarColor {f} {
     $m add separator
     $m add cascade -label [msgcat::mc {Colorbar}] -menu $m.colorbar
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {Colormap Parameters}]..." \
+    $m add checkbutton -label [msgcat::mc {Colormap Parameters}] \
 	-variable pbuttons(color,params) \
 	-command {UpdateButtons buttons(color)}
 
@@ -444,12 +444,12 @@ proc UpdateColorMenu {} {
 		$ds9(mb).color entryconfig [msgcat::mc {User}] \
 		    -state normal
 
-		UpdateColorMenuExternal default normal
-		UpdateColorMenuExternal h5 normal
-		UpdateColorMenuExternal matplotlib normal
-		UpdateColorMenuExternal cubehelix normal
-		UpdateColorMenuExternal gist normal
-		UpdateColorMenuExternal topo normal
+		UpdateColorButtonExternal default normal
+		UpdateColorButtonExternal h5 normal
+		UpdateColorButtonExternal matplotlib normal
+		UpdateColorButtonExternal cubehelix normal
+		UpdateColorButtonExternal gist normal
+		UpdateColorButtonExternal topo normal
 	    }
 	    rgb {
 		foreach cmap $icolorbar(default,cmaps) {
@@ -469,12 +469,12 @@ proc UpdateColorMenu {} {
 		$ds9(mb).color entryconfig [msgcat::mc {User}] \
 		    -state disable
 
-		UpdateColorMenuExternal default disable
-		UpdateColorMenuExternal h5 disable
-		UpdateColorMenuExternal matplotlib disable
-		UpdateColorMenuExternal cubehelix disable
-		UpdateColorMenuExternal gist disable
-		UpdateColorMenuExternal topo disable
+		UpdateColorButtonExternal default disable
+		UpdateColorButtonExternal h5 disable
+		UpdateColorButtonExternal matplotlib disable
+		UpdateColorButtonExternal cubehelix disable
+		UpdateColorButtonExternal gist disable
+		UpdateColorButtonExternal topo disable
 	    }
 	}
     } else {
@@ -489,20 +489,32 @@ proc UpdateColorMenu {} {
 	$ds9(mb).color entryconfig [msgcat::mc {Topographic}] -state normal
 	$ds9(mb).color entryconfig [msgcat::mc {User}] -state normal
 
-	UpdateColorMenuExternal default normal
-	UpdateColorMenuExternal h5 normal
-	UpdateColorMenuExternal matplotlib normal
-	UpdateColorMenuExternal cubehelix normal
-	UpdateColorMenuExternal gist normal
-	UpdateColorMenuExternal topo normal
+	UpdateColorButtonExternal default normal
+	UpdateColorButtonExternal h5 normal
+	UpdateColorButtonExternal matplotlib normal
+	UpdateColorButtonExternal cubehelix normal
+	UpdateColorButtonExternal gist normal
+	UpdateColorButtonExternal topo normal
     }
 }
 
-proc UpdateColorMenuExternal {which state} {
+proc UpdateColorButtonExternal {which state} {
     global icolorbar
+    global colorbar
     global ds9
 
     foreach cmap $icolorbar($which,cmaps) {
-	$ds9(buttons).color.$cmap configure -state $state
+	switch $state {
+	    normal {
+		if {$colorbar(map) == $cmap} {
+		    $ds9(buttons).color.$cmap configure -state active
+		} else {
+		    $ds9(buttons).color.$cmap configure -state normal
+		}
+	    }
+	    disable {
+		$ds9(buttons).color.$cmap configure -state disable
+	    }
+	}
     }
 }
